@@ -1,6 +1,6 @@
 var searchData=
 [
   ['deletion_20support_20functions_0',['Safe widget deletion support functions',['../group__fl__del__widget.html',1,'']]],
-  ['dialogs_20classes_20and_20functions_1',['Common Dialogs classes and functions',['../group__group__comdlg.html',1,'']]],
+  ['dialog_20classes_20and_20functions_1',['Common Dialog Classes and Functions',['../group__group__comdlg.html',1,'']]],
   ['drawing_20functions_2',['Drawing functions',['../group__fl__drawings.html',1,'']]]
 ];
